@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -62,9 +63,7 @@
 #include "strings.hrc"
 #include "res_bmp.hrc"
 #include "ViewShell.hxx"
-#ifndef SD_FRAMW_VIEW_HXX
 #include "FrameView.hxx"
-#endif
 #include "sdattr.hxx"
 #include "tpoption.hrc"
 #include "optsitem.hxx"
@@ -833,3 +832,5 @@ SfxTabPage* SdModule::CreateTabPage( USHORT nId, Window* pParent, const SfxItemS
 
     return pRet;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
